@@ -10,11 +10,13 @@ sub _jspon_fields {
         id
         class
         class_meta
+        class_version
         root
         deleted
         tied
         ref
         data
+        backend_data
     );
 }
 
@@ -36,6 +38,12 @@ has class_meta_field => (
     default => "__META__",
 );
 
+has class_version_field => (
+    isa => "Str",
+    is  => "ro",
+    default => "__VERSION__",
+);
+
 has root_field => (
     isa => "Str",
     is  => "ro",
@@ -66,6 +74,12 @@ has data_field => (
     default => "data",
 );
 
+has backend_data_field => (
+    isa => "Str",
+    is  => "ro",
+    default => "backend_data",
+);
+
 has inline_data => (
     isa => "Bool",
     is  => "ro",
@@ -146,7 +160,7 @@ C<$ref> according to the JSPON spec.
 =item inline_data
 
 Determines whether or not the entry data keys are escaped and the data is
-stored in the same top level mapping, or inside a the C<data_field> key.
+stored in the same top level mapping, or inside the C<data_field> key.
 
 =back
 
