@@ -14,7 +14,7 @@ sub p {
     KiokuDB::Test::Person->new(@args);
 }
 
-with qw(KiokuDB::Test::Fixture) => { excludes => [qw/populate sort/] };
+with qw(KiokuDB::Test::Fixture) => { -excludes => [qw/populate sort/] };
 
 sub sort { -100 }
 
