@@ -7,6 +7,8 @@ use Carp qw(croak);
 
 use KiokuDB::TypeMap::Entry::Compiled;
 
+no warnings 'recursion';
+
 use namespace::clean -except => 'meta';
 
 with qw(KiokuDB::TypeMap::Entry);
@@ -49,7 +51,12 @@ sub compile {
             },
             expand_method => sub {
                 my ( $linker, $entry ) = @_;
-                return $entry->data;
+
+                my $obj = $entry->data;
+
+                $linker->register_object( $entry => $obj );
+
+                return $obj;
             },
             id_method => "generate_uuid",
             refresh_method => sub {
